@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-__version__ = '1.0.10'
+__version__ = '1.0.14'
 
 from    pathlib                 import Path
 
@@ -22,7 +22,7 @@ from    pftel_client.types      import Response
 
 from    argparse                import  Namespace, ArgumentParser
 from    argparse                import  RawTextHelpFormatter
-
+from    pftag                   import  pftag
 from    .                       import  data
 
 def parser_setup(str_desc) -> ArgumentParser:
@@ -89,6 +89,11 @@ def parser_setup(str_desc) -> ArgumentParser:
                 default = '',
                 help    = 'URL (including port if needed) for the pftel server'
     )
+    parser.add_argument(
+                '--pftelDB',
+                default = '',
+                help    = 'DB path for log POST in the pftel server'
+    )
     parser.add_argument(
                 '--log',
                 default = '',
@@ -321,4 +326,80 @@ class Pflog:
 
     def __call__(self, message:str, *args: Any, **kwds: Any) -> Any:
         self.options.log = message
-        return self.run()
\ No newline at end of file
+        return self.run()
+
+def pfprint(pftelspec:str, message:str, **kwargs) -> str:
+    """
+    A simple "standalone" function for "printing" to
+    a pftel server, analogous to the old C-style printf
+    type functions.
+
+    This function will create a `pflog` object and use this
+    to transmit the <message> with optional kwargs
+    elements.
+
+    Args:
+        pftelspec (str): A pftelFQS string denoting
+        message (str): a message to POST
+
+    kwargs:
+        appName     = <appName>
+        execTime    = <execTime>
+
+    Returns:
+        str: the return from the pftel server
+    """
+    appName:str         = 'pfprint'
+    execTime:str        = '-1'
+    d_log:dict          = {}
+    protocol:str        = ""
+    skip:str            = ""
+    hostport:str        = ""
+    api:str             = ""
+    version:str         = ""
+    logObject:str       = ""
+    logCollection:str   = ""
+    logEvent:str        = ""
+    d_log               = {
+        "status":       False,
+        "reply":        None,
+        "URLspec":      pftelspec
+    }
+
+    for k,v in kwargs.items():
+        if k == 'appName':  appName     = v
+        if k == 'execTime': execTime    = v
+    try:
+        tagger:pftag.Pftag  = pftag.Pftag({})
+        d_tag:dict          = tagger(pftelspec)
+        pftelsub:str        = d_tag['result']
+        d_log['URLspec']    = d_tag['result']
+        protocol,       \
+        skip,           \
+        hostport,       \
+        api,            \
+        version,        \
+        logObject,      \
+        logCollection,  \
+        logEvent = pftelsub.split('/')
+        try:
+            tlog:Pflog        = Pflog( {
+                'log'           : message,
+                'pftelURL'      : protocol + '//' + hostport,
+                'logObject'     : logObject,
+                'logCollection' : logCollection,
+                'logEvent'      : logEvent,
+                'appName'       : appName,
+                'execTime'      : execTime,
+                'verbosity'     : '1'
+            })
+            try:
+                d_log:dict          = tlog.run()
+            except Exception as e:
+                print('%s' % e)
+                print("ERROR - could not POST to remote server!")
+        except:
+            print("ERROR - could not connect to remote server!")
+    except:
+        print("ERROR -- the pftel DB URL spec seems invalid!")
+    return d_log
